set daemon <poll_interval>

set logfile /var/log/plesk/modules/monit.log
set statefile <plesk_dir>/var/modules/watchdog/run/monit.state
set pidfile <monit_pidfile>

set httpd port <monit_tcp_port> and use address 127.0.0.1
	allow 127.0.0.1
	allow <monit_login>:<monit_password>

set collector http://127.0.0.1:<wdcollect_port>

# Plesk apache
check process plesk_apache
	with pidfile "/var/run/sw-cp-server.pid"
	start = "<plesk_apache_start>"
	stop = "<plesk_apache_stop>"
	if failed host localhost port 8443 type tcpssl send "GET /favicon.ico HTTP/1.1\r\n\r\n" expect "HTTP/1\.[01x] [1-4][0-9]{2} .*\r\n" with timeout <plesk_apache_connection_timeout> seconds then restart
	if <plesk_apache_timeout_restarts> restarts within <plesk_apache_timeout_cycles> cycles then timeout
	every <plesk_apache_cycles> cycles
	mode <plesk_apache_mode>

# sw-engine
check process sw_engine
	with pidfile "/var/run/sw-engine.pid"
	start = "<sw_engine_start>"
	stop = "<sw_engine_stop>"
	if failed unixsocket /var/run/sw-engine.sock with timeout <sw_engine_connection_timeout> seconds then restart
	if <sw_engine_timeout_restarts> restarts within <sw_engine_timeout_cycles> cycles then timeout
	every <sw_engine_cycles> cycles
	mode <sw_engine_mode>

# Apache
check process apache
	with pidfile "/var/run/apache2.pid"
	start = "<apache_start>"
	stop = "<apache_stop>"
	if failed host <default_apache_ip> port <apache_port> send "GET / HTTP/1.1\r\nHost: <default_apache_ip>\r\n\r\n" expect "HTTP/1\.[01x] [1-4][0-9]{2} .*\r\n" with timeout <apache_connection_timeout> seconds then restart
	if <apache_timeout_restarts> restarts within <apache_timeout_cycles> cycles then timeout
	every <apache_cycles> cycles
	mode <apache_mode>

check process xinetd with pidfile /var/run/xinetd.pid
    start = "/etc/init.d/xinetd start"
    stop = "/etc/init.d/xinetd stop"

# Tomcat
check process tomcat with pidfile "/var/run/tomcat6.pid"
	start = "<tomcat_start>"
	stop = "<tomcat_stop>"
	if failed port 9080 with timeout <tomcat_connection_timeout> seconds then restart
	if <tomcat_timeout_restarts> restarts within <tomcat_timeout_cycles> cycles then timeout
	every <tomcat_cycles> cycles
	mode <tomcat_mode>

# ColdFusion
check host coldfusion with address 127.0.0.1
	start = "<coldfusion_start>"
	stop = "<coldfusion_stop>"
	if failed port <coldfusion_port> protocol http with timeout <coldfusion_connection_timeout> seconds then restart
	if <coldfusion_timeout_restarts> restarts within <coldfusion_timeout_cycles> cycles then timeout
	every <coldfusion_cycles> cycles
	mode <coldfusion_mode>

# MySQL
check process mysql
	with pidfile "<mysql_pid>"
	start = "<mysql_start>"
	stop = "<mysql_stop>"
	if failed unixsocket /var/run/mysqld/mysqld.sock with timeout <mysql_connection_timeout> seconds then restart
	if <mysql_timeout_restarts> restarts within <mysql_timeout_cycles> cycles then timeout
	every <mysql_cycles> cycles
	mode <mysql_mode>

# PostgreSQL
check process postgresql
	with pidfile "/var/lib/postgresql/8.4/main/postmaster.pid"
	start = "<postgresql_start>"
	stop = "<postgresql_stop>"
	if failed unixsocket /var/run/postgresql/.s.PGSQL.5432 with timeout <postgresql_connection_timeout> seconds then restart
	if <postgresql_timeout_restarts> restarts within <postgresql_timeout_cycles> cycles then timeout
	every <postgresql_cycles> cycles
	mode <postgresql_mode>

# SpamAssassin
check process psa_spamassassin
	with pidfile "/var/run/spamd.pid"
	start = "<psa_spamassassin_start>"
	stop = "<psa_spamassassin_stop>"
	if failed host localhost port 783 <spamassassin_protocol_check> with timeout <psa_spamassassin_connection_timeout> seconds then restart
	if <psa_spamassassin_timeout_restarts> restarts within <psa_spamassassin_timeout_cycles> cycles then timeout
	every <psa_spamassassin_cycles> cycles
	mode <psa_spamassassin_mode>

# Nginx
check process nginx
	with pidfile /var/run/nginx.pid
	start = "<nginx_start>"
	stop = "<nginx_stop>"
	if failed host <default_external_ip> port <nginx_port> send "GET / HTTP/1.1\r\nHost: <default_external_ip>\r\n\r\n" expect "HTTP/1\.[01x] ([1-4][0-9]{2}|502) .*\r\n" with timeout <nginx_connection_timeout> seconds then restart
	if <nginx_timeout_restarts> restarts within <nginx_timeout_cycles> cycles then timeout
	every <nginx_cycles> cycles
	mode <nginx_mode>

# php-fpm
check process php_fpm
	with pidfile /var/run/php5-fpm.pid
	start = "<php_fpm_start>"
	stop = "<php_fpm_stop>"
	if <php_fpm_timeout_restarts> restarts within <php_fpm_timeout_cycles> cycles then timeout
	every <php_fpm_cycles> cycles
	mode <php_fpm_mode>

# fail2ban
check process fail2ban
	with pidfile /var/run/fail2ban/fail2ban.pid
	start = "<fail2ban_start>"
	stop = "<fail2ban_stop>"
	if <fail2ban_timeout_restarts> restarts within <fail2ban_timeout_cycles> cycles then timeout
	if failed unixsocket /var/run/fail2ban/fail2ban.sock with timeout <fail2ban_connection_timeout> seconds then restart
	every <fail2ban_cycles> cycles
	mode <fail2ban_mode>
